@@ -22,10 +22,11 @@ class DataURI(BaseSite):
     """Data URI schemes."""
 
     @staticmethod
-    def crawler(session: typing.Session, link: Link) -> typing.NoReturn:  # pylint: disable=unused-argument
+    def crawler(timestamp: typing.Datetime, session: typing.Session, link: Link) -> typing.NoReturn:  # pylint: disable=unused-argument
         """Crawler hook for data URIs.
 
         Args:
+            timestamp: Timestamp of the worker node reference.
             session (:class:`requests.Session`): Session object with proxy settings.
             link: Link object to be crawled.
 
@@ -41,7 +42,7 @@ class DataURI(BaseSite):
         raise LinkNoReturn(link)
 
     @staticmethod
-    def loader(driver: typing.Driver, link: Link) -> typing.NoReturn:  # pylint: disable=unused-argument
+    def loader(timestamp: typing.Datetime, driver: typing.Driver, link: Link) -> typing.NoReturn:  # pylint: disable=unused-argument
         """Not implemented.
 
         Raises:
